@@ -41,8 +41,8 @@ pub fn event_input(
   // Set up buffer and variables for moving in it
   let mut buffer = initial_buffer;
   if buffer.len() == 0 { buffer.push("\n".to_string()); } // The buffer mustn't be empty
-  let mut lindex = 0; // Line index, lin-dex
-  let mut chindex = 0; // Char index, ch-index
+  let mut lindex = buffer.len() - 1; // Line index, lin-dex
+  let mut chindex = buffer[lindex].len() - 1; // Char index, ch-index
 
   // Variable for tracking how many steps back in history
   // we are when moving back in history
@@ -81,11 +81,14 @@ pub fn event_input(
       state,
       &syntax,
       &mut buffer.iter().map(|line| &line[..]),
-      prefix,
-      Some((lindex, chindex)),
-      0,
-      false,
-      false,
+      super::print::PrintConf {
+        prefix: prefix,
+        cursor: Some((lindex, chindex)),
+        start_line: 0,
+        literal: false,
+        numbered: false,
+        separator: true,
+      },
     )?;
     // And move to the positions returned
     if dists.cursor_y > 0 {
@@ -115,8 +118,8 @@ pub fn event_input(
   
         // If doing anything but moving up/down, clear goal_chindex
         if (key.code != KeyCode::Up &&
-           key.code != KeyCode::Down ) ||
-           key.modifiers != KeyModifiers::NONE
+          key.code != KeyCode::Down ) ||
+          key.modifiers != KeyModifiers::NONE
         {
           goal_chindex = None;
         }
@@ -272,25 +275,34 @@ pub fn event_input(
                   .get(hoffset) // Get history at offset
                   .map(|line| line.clone()) // Convert from &str to String
                   .unwrap_or(semi_history.clone()) // If none we have arrived in the present
-              )
+              );
+              // Set cursor to tail of history entry
+              lindex = 0;
+              chindex = buffer[0].len() - 1;
             }
             else {
               // First move to the indicated line, if possible
               match key.code {
-                KeyCode::Up => { lindex = lindex.saturating_sub(1); },
-                KeyCode::Down => { if lindex < buffer.len() - 1 { lindex += 1; } },
+                KeyCode::Up => {
+                  lindex = lindex.saturating_sub(1);
+                },
+                KeyCode::Down => { 
+                  if lindex < buffer.len() - 1 { lindex += 1; }
+                  // If on last line set chindex to max, so goal_chindex keeps cursor at EOL
+                  else { chindex = usize::MAX }
+                },
                 _ => (),
               }
-            }
-            // Then try to go to goal_chindex and place chindex within the new line
-            match goal_chindex {
-              Some(tmp) => { chindex = tmp; },
-              None => (),
-            }
-            // If current chindex is too big, save it as goal and go to nearest valid chindex
-            if chindex >= buffer[lindex].len() {
-              goal_chindex = Some(chindex);
-              chindex = buffer[lindex].len() - 1;
+              // Then try to go to goal_chindex and place chindex within the new line
+              match goal_chindex {
+                Some(tmp) => { chindex = tmp; },
+                None => (),
+              }
+              // If current chindex is too big, save it as goal and go to nearest valid chindex
+              if chindex >= buffer[lindex].len() {
+                goal_chindex = Some(chindex);
+                chindex = buffer[lindex].len() - 1;
+              }
             }
           },
   
@@ -325,11 +337,14 @@ pub fn event_input(
     state,
     &syntax,
     &mut buffer.iter().map(|line| &line[..]),
-    prefix,
-    None,
-    0,
-    false,
-    false,
+    super::print::PrintConf {
+      prefix: prefix,
+      cursor: None,
+      start_line: 0,
+      numbered: false,
+      literal: false,
+      separator: true,
+    },
   )?;
   // Then flush and return
   stdout.flush()?;
